@@ -152,6 +152,7 @@ namespace
       masks["JobMgrMsg"]          = XrdCl::JobMgrMsg;
       masks["PlugInMgrMsg"]       = XrdCl::PlugInMgrMsg;
       masks["ExDbgMsg"]           = XrdCl::ExDbgMsg;
+      masks["TlsMsg"]             = XrdCl::TlsMsg;
     }
 
     //--------------------------------------------------------------------------
@@ -255,6 +256,7 @@ namespace XrdCl
   DefaultEnv::DefaultEnv()
   {
     Log *log = GetLog();
+    log->Debug( UtilityMsg, "Initializing xrootd client version: %s", XrdVERSION );
 
     //--------------------------------------------------------------------------
     // Declate the variables to be processed
@@ -277,6 +279,7 @@ namespace XrdCl
     REGISTER_VAR_INT( varsInt, "LoadBalancerTTL",         DefaultLoadBalancerTTL         );
     REGISTER_VAR_INT( varsInt, "CPInitTimeout",           DefaultCPInitTimeout           );
     REGISTER_VAR_INT( varsInt, "CPTPCTimeout",            DefaultCPTPCTimeout            );
+    REGISTER_VAR_INT( varsInt, "CPTimeout",               DefaultCPTimeout               );
     REGISTER_VAR_INT( varsInt, "TCPKeepAlive",            DefaultTCPKeepAlive            );
     REGISTER_VAR_INT( varsInt, "TCPKeepAliveTime",        DefaultTCPKeepAliveTime        );
     REGISTER_VAR_INT( varsInt, "TCPKeepAliveInterval",    DefaultTCPKeepAliveInterval    );
@@ -297,6 +300,12 @@ namespace XrdCl
     REGISTER_VAR_INT( varsInt, "TlsNoData",               DefaultTlsNoData               );
     REGISTER_VAR_INT( varsInt, "TlsMetalink",             DefaultTlsMetalink             );
     REGISTER_VAR_INT( varsInt, "ZipMtlnCksum",            DefaultZipMtlnCksum            );
+    REGISTER_VAR_INT( varsInt, "IPNoShuffle",             DefaultIPNoShuffle             );
+    REGISTER_VAR_INT( varsInt, "WantTlsOnNoPgrw",         DefaultWantTlsOnNoPgrw         );
+    REGISTER_VAR_INT( varsInt, "RetryWrtAtLBLimit",       DefaultRetryWrtAtLBLimit       );
+    REGISTER_VAR_INT( varsInt, "XRateThreshold",          DefaultXRateThreshold          );
+    REGISTER_VAR_INT( varsInt, "CpRetry",                 DefaultCpRetry                 );
+    REGISTER_VAR_INT( varsInt, "CpUsePgWrtRd",            DefaultCpUsePgWrtRd            );
 
     REGISTER_VAR_STR( varsStr, "ClientMonitor",           DefaultClientMonitor           );
     REGISTER_VAR_STR( varsStr, "ClientMonitorParam",      DefaultClientMonitorParam      );
@@ -308,6 +317,8 @@ namespace XrdCl
     REGISTER_VAR_STR( varsStr, "OpenRecovery",            DefaultOpenRecovery            );
     REGISTER_VAR_STR( varsStr, "GlfnRedirector",          DefaultGlfnRedirector          );
     REGISTER_VAR_STR( varsStr, "TlsDbgLvl",               DefaultTlsDbgLvl               );
+    REGISTER_VAR_STR( varsStr, "CpTarget",                DefaultCpTarget                );
+    REGISTER_VAR_STR( varsStr, "CpRetryPolicy",           DefaultCpRetryPolicy           );
 
     //--------------------------------------------------------------------------
     // Process the configuration files
@@ -335,6 +346,24 @@ namespace XrdCl
     else
       log->Debug( UtilityMsg, "Unable to find user home directory." );
 
+    char *conffile = getenv( "XRD_CLCONFFILE" );
+    if( conffile )
+    {
+      st = Utils::ProcessConfig( userConfig, conffile );
+      if( !st.IsOK() )
+        log->Debug( UtilityMsg, "Unable to process %s file: %s",
+                    conffile, st.ToString().c_str() );
+    }
+
+    char *confdir = getenv( "XRD_CLCONFDIR" );
+    if( confdir )
+    {
+      st = Utils::ProcessConfigDir( userConfig, confdir );
+      if( !st.IsOK() )
+        log->Debug( UtilityMsg, "Unable to process %s file: %s",
+                    confdir, st.ToString().c_str() );
+    }
+
     std::map<std::string, std::string>::iterator it;
 
     for( it = config.begin(); it != config.end(); ++it )
@@ -831,6 +860,7 @@ namespace XrdCl
     log->SetTopicName( PlugInMgrMsg,       "PlugInMgr" );
     log->SetTopicName( ExDbgMsg,           "ExDbgMsg" );
     log->SetTopicName( TlsMsg,             "TlsMsg" );
+    log->SetTopicName( ZipMsg,             "ZipMsg" );
   }
 
 }
