@@ -85,8 +85,8 @@ const char *ffFmt1 =
 const char *ffFmt2 =
   "\"flow-id\":{"
     "\"afi\":\"ipv%c\","            //-> ipv4 | ipv6
-    "\"src-ip\":\"%s\","            //   source which is always server (us)
-    "\"dst-ip\":\"%s\","            //   dest   which is always client
+    "\"src-ip\":\"%s\","            //   source client for put o/w server
+    "\"dst-ip\":\"%s\","            //   dest   server for put o/w client
     "\"protocol\":\"tcp\","
     "\"src-port\":%d,"
     "\"dst-port\":%d"
@@ -149,8 +149,19 @@ bool XrdNetPMarkFF::Emit(const char *state, const char *cT, const char *eT)
 
    SockStats(ss);
 
-   int n = snprintf(msgBuff, sizeof(msgBuff), ffHdr, state, cT, eT,
+// Note that the supplier of the data is the source. Hence, for put requests
+// the client is designated as the source o/w it is the server. So, on a
+// put request the number of bytes we recived is the number of bytes the
+// source (i.e. client) sent. Note the temlate is "usage: recv sent".
+//
+   int n;
+   if (appName && !strcmp(appName, "http-put"))
+      {n = snprintf(msgBuff, sizeof(msgBuff), ffHdr, state, cT, eT,
+                             ss.bSent, ss.bRecv, ss.msRTT, ss.usRTT);
+      } else {
+       n = snprintf(msgBuff, sizeof(msgBuff), ffHdr, state, cT, eT,
                              ss.bRecv, ss.bSent, ss.msRTT, ss.usRTT);
+      }
 
    if (n + ffTailsz >= (int)sizeof(msgBuff))
       {eDest->Emsg("PMarkFF", "invalid json; msgBuff truncated.");
@@ -294,6 +305,10 @@ void XrdNetPMarkFF::SockStats(struct sockStats &ss)
    struct tcp_info tcpInfo;
    socklen_t  tiLen = sizeof(tcpInfo);
 
+// The data returned is from the server's perspective. This must be
+// resolved by the caller as to which perspective should be presented.
+// Note that for put requests the source is the client.
+//
    if (getsockopt(sockFD, IPPROTO_TCP, TCP_INFO, (void *)&tcpInfo, &tiLen) == 0)
       {ss.bRecv = static_cast<uint64_t>(tcpInfo.tcpi_bytes_received);
        ss.bSent = static_cast<uint64_t>(tcpInfo.tcpi_bytes_acked);
@@ -386,9 +401,20 @@ bool XrdNetPMarkFF::Start(XrdNetAddrInfo &addr)
        return false;
       }
 
+// Note that by convention FF packets the supplier of the data is designated
+// as the source. We only know this at this point for http requests and even
+// then it's hardly accurate. So, for put requests the src if the client.  
+// Ottherwise, we designate the server as the source.
+//
    char bseg2[256];
-   int len2 = snprintf(bseg2, sizeof(bseg2), ffFmt2,
+   int len2;
+   if (appName && !strcmp(appName, "http-put"))
+      {len2 = snprintf(bseg2, sizeof(bseg2), ffFmt2,
+                              clType, clIP, svIP, clPort, svPort);
+      } else {
+       len2 = snprintf(bseg2, sizeof(bseg2), ffFmt2,
                               clType, svIP, clIP, svPort, clPort);
+      }
    if (len2 >= (int)sizeof(bseg2))
       {eDest->Emsg("PMarkFF", "invalid json; cl bseg2 truncated.");
        return false;
