@@ -29,11 +29,11 @@
 /******************************************************************************/
 
 #include <unistd.h>
-#include <errno.h>
+#include <cerrno>
 #include <strings.h>
 #include <limits.h>
 #include <fcntl.h>
-#include <stdio.h>
+#include <cstdio>
 #include <sys/param.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -55,7 +55,7 @@
 
 extern XrdSysError OssEroute;
 
-extern XrdOucTrace OssTrace;
+extern XrdSysTrace OssTrace;
 
 /******************************************************************************/
 /*                                R e n a m e                                 */
