@@ -32,8 +32,8 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <ctype.h>
-#include <stdio.h>
+#include <cctype>
+#include <cstdio>
 #include <strings.h>
 
 #include "XrdOuc/XrdOucMsubs.hh"
