@@ -21,14 +21,12 @@
 #include <algorithm>
 #include <sys/statvfs.h>
 
-#include "XrdCl/XrdClConstants.hh"
 #include "XrdCl/XrdClURL.hh"
 
 #include "XrdOuc/XrdOucEnv.hh"
 #include "XrdOuc/XrdOucUtils.hh"
 #include "XrdOuc/XrdOucPrivateUtils.hh"
 
-#include "XrdSys/XrdSysPthread.hh"
 #include "XrdSys/XrdSysTimer.hh"
 #include "XrdSys/XrdSysTrace.hh"
 #include "XrdSys/XrdSysXAttr.hh"
@@ -43,25 +41,19 @@
 #include "XrdPfcInfo.hh"
 #include "XrdPfcIOFile.hh"
 #include "XrdPfcIOFileBlock.hh"
+#include "XrdPfcResourceMonitor.hh"
 
 extern XrdSysXAttr *XrdSysXAttrActive;
 
 using namespace XrdPfc;
 
-Cache * Cache::m_instance = 0;
-
-XrdScheduler *Cache::schedP = 0;
+Cache           *Cache::m_instance = nullptr;
+XrdScheduler    *Cache::schedP = nullptr;
 
 
-void *ResourceMonitorHeartBeatThread(void*)
+void *ResourceMonitorThread(void*)
 {
-   Cache::GetInstance().ResourceMonitorHeartBeat();
-   return 0;
-}
-
-void *PurgeThread(void*)
-{
-   Cache::GetInstance().Purge();
+   Cache::ResMon().main_thread_function();
    return 0;
 }
 
@@ -103,11 +95,13 @@ XrdOucCache *XrdOucGetCache(XrdSysLogger *logger,
       err.Say("Config Proxy file cache initialization failed.");
       return 0;
    }
-   err.Say("------ Proxy file cache initialization completed.");
+   err.Say("++++++ Proxy file cache initialization completed.");
 
    {
       pthread_t tid;
 
+      XrdSysThread::Run(&tid, ResourceMonitorThread, 0, 0, "XrdPfc ResourceMonitor");
+
       for (int wti = 0; wti < instance.RefConfiguration().m_wqueue_threads; ++wti)
       {
          XrdSysThread::Run(&tid, ProcessWriteTaskThread, 0, 0, "XrdPfc WriteTasks ");
@@ -117,10 +111,6 @@ XrdOucCache *XrdOucGetCache(XrdSysLogger *logger,
       {
          XrdSysThread::Run(&tid, PrefetchThread, 0, 0, "XrdPfc Prefetch ");
       }
-
-      XrdSysThread::Run(&tid, ResourceMonitorHeartBeatThread, 0, 0, "XrdPfc ResourceMonitorHeartBeat");
-
-      XrdSysThread::Run(&tid, PurgeThread, 0, 0, "XrdPfc Purge");
    }
 
    XrdPfcFSctl* pfcFSctl = new XrdPfcFSctl(instance, logger);
@@ -132,27 +122,6 @@ XrdOucCache *XrdOucGetCache(XrdSysLogger *logger,
 
 //==============================================================================
 
-void Configuration::calculate_fractional_usages(long long  du,      long long  fu,
-                                                double    &frac_du, double    &frac_fu)
-{
-  // Calculate fractional disk / file usage and clamp them to [0, 1].
-
-  // Fractional total usage above LWM:
-  // - can be > 1 if usage is above HWM;
-  // - can be < 0 if triggered via age-based-purging.
-  frac_du = (double) (du - m_diskUsageLWM) / (m_diskUsageHWM - m_diskUsageLWM);
-
-  // Fractional file usage above baseline.
-  // - can be > 1 if file usage is above max;
-  // - can be < 0 if file usage is below baseline.
-  frac_fu = (double) (fu - m_fileUsageBaseline) / (m_fileUsageMax - m_fileUsageBaseline);
-
-  frac_du = std::min( std::max( frac_du, 0.0), 1.0 );
-  frac_fu = std::min( std::max( frac_fu, 0.0), 1.0 );
-}
-
-//==============================================================================
-
 Cache &Cache::CreateInstance(XrdSysLogger *logger, XrdOucEnv *env)
 {
    assert (m_instance == 0);
@@ -160,9 +129,10 @@ Cache &Cache::CreateInstance(XrdSysLogger *logger, XrdOucEnv *env)
    return *m_instance;
 }
 
-      Cache&         Cache::GetInstance() { return *m_instance; }
-const Cache&         Cache::TheOne()      { return *m_instance; }
-const Configuration& Cache::Conf()        { return  m_instance->RefConfiguration(); }
+      Cache&           Cache::GetInstance() { return *m_instance; }
+const Cache&           Cache::TheOne()      { return *m_instance; }
+const Configuration&   Cache::Conf()        { return  m_instance->RefConfiguration(); }
+      ResourceMonitor& Cache::ResMon()      { return  m_instance->RefResMon(); }
 
 bool Cache::Decide(XrdOucCacheIO* io)
 {
@@ -193,19 +163,14 @@ Cache::Cache(XrdSysLogger *logger, XrdOucEnv *env) :
    m_traceID("Cache"),
    m_oss(0),
    m_gstream(0),
+   m_purge_pin(0),
    m_prefetch_condVar(0),
    m_prefetch_enabled(false),
    m_RAM_used(0),
    m_RAM_write_queue(0),
    m_RAM_std_size(0),
    m_isClient(false),
-   m_in_purge(false),
-   m_active_cond(0),
-   m_stats_n_purge_cond(0),
-   m_fs_state(0),
-   m_last_scan_duration(0),
-   m_last_purge_duration(0),
-   m_spt_state(SPTS_Idle)
+   m_active_cond(0)
 {
    // Default log level is Warning.
    m_trace->What = 2;
@@ -352,6 +317,15 @@ void Cache::ProcessWriteTasks()
    }
 }
 
+long long Cache::WritesSinceLastCall()
+{
+   // Called from ResourceMonitor for an alternative estimation of disk writes.
+   XrdSysCondVarHelper lock(&m_writeQ.condVar);
+   long long ret = m_writeQ.writes_between_purges;
+   m_writeQ.writes_between_purges = 0;
+   return ret;
+}
+
 //==============================================================================
 
 char* Cache::RequestRAM(long long size)
@@ -497,9 +471,9 @@ File* Cache::GetFile(const std::string& path, IO* io, long long off, long long f
 void Cache::ReleaseFile(File* f, IO* io)
 {
    // Called from virtual IO::DetachFinalize.
-   
+
    TRACE(Debug, "ReleaseFile " << f->GetLocalPath() << ", io " << io);
-   
+
    {
      XrdSysCondVarHelper lock(&m_active_cond);
 
@@ -591,6 +565,7 @@ void Cache::dec_ref_cnt(File* f, bool high_debug)
    int tlvl = high_debug ? TRACE_Debug : TRACE_Dump;
    int cnt;
 
+   bool emergency_close = false;
    {
      XrdSysCondVarHelper lock(&m_active_cond);
 
@@ -605,15 +580,16 @@ void Cache::dec_ref_cnt(File* f, bool high_debug)
         if (cnt == 1)
         {
            TRACE_INT(tlvl, "dec_ref_cnt " << f->GetLocalPath() << " is in shutdown, ref_cnt = " << cnt
-                     << " -- deleting File object without further ado");
-           delete f;
+                     << " -- closing and deleting File object without further ado");
+            emergency_close = true;
         }
         else
         {
            TRACE_INT(tlvl, "dec_ref_cnt " << f->GetLocalPath() << " is in shutdown, ref_cnt = " << cnt
                      << " -- waiting");
+           f->dec_ref_cnt();
+           return;
         }
-        return;
      }
      if (cnt > 1)
      {
@@ -621,6 +597,12 @@ void Cache::dec_ref_cnt(File* f, bool high_debug)
         return;
      }
    }
+   if (emergency_close)
+   {
+      f->Close();
+      delete f;
+      return;
+   }
 
    if (cnt == 1)
    {
@@ -635,6 +617,8 @@ void Cache::dec_ref_cnt(File* f, bool high_debug)
       }
    }
 
+   bool finished_p = false;
+   ActiveMap_i act_it;
    {
       XrdSysCondVarHelper lock(&m_active_cond);
 
@@ -642,46 +626,54 @@ void Cache::dec_ref_cnt(File* f, bool high_debug)
       TRACE_INT(tlvl, "dec_ref_cnt " << f->GetLocalPath() << ", cnt after sync_check and dec_ref_cnt = " << cnt);
       if (cnt == 0)
       {
-         ActiveMap_i it = m_active.find(f->GetLocalPath());
-         m_active.erase(it);
+         act_it = m_active.find(f->GetLocalPath());
+         act_it->second = 0;
 
-         m_closed_files_stats.insert(std::make_pair(f->GetLocalPath(), f->DeltaStatsFromLastCall()));
-
-         if (m_gstream)
-         {
-            const Stats       &st = f->RefStats();
-            const Info::AStat *as = f->GetLastAccessStats();
-
-            char buf[4096];
-            int  len = snprintf(buf, 4096, "{\"event\":\"file_close\","
-                                 "\"lfn\":\"%s\",\"size\":%lld,\"blk_size\":%d,\"n_blks\":%d,\"n_blks_done\":%d,"
-                                 "\"access_cnt\":%zu,\"attach_t\":%lld,\"detach_t\":%lld,\"remotes\":%s,"
-                                 "\"b_hit\":%lld,\"b_miss\":%lld,\"b_bypass\":%lld,"
-                                 "\"b_todisk\":%lld,\"b_prefetch\":%lld,\"n_cks_errs\":%d}",
-                                 f->GetLocalPath().c_str(), f->GetFileSize(), f->GetBlockSize(),
-                                 f->GetNBlocks(), f->GetNDownloadedBlocks(),
-                                 f->GetAccessCnt(), (long long) as->AttachTime, (long long) as->DetachTime,
-                                 f->GetRemoteLocations().c_str(),
-                                 as->BytesHit, as->BytesMissed, as->BytesBypassed,
-                                 st.m_BytesWritten, f->GetPrefetchedBytes(), st.m_NCksumErrors
-            );
-            bool suc = false;
-            if (len < 4096)
-            {
-               suc = m_gstream->Insert(buf, len + 1);
-            }
-            if ( ! suc)
-            {
-               TRACE(Error, "Failed g-stream insertion of file_close record, len=" << len);
-            }
-         }
-
-         delete f;
+         finished_p = true;
       }
    }
+   if (finished_p)
+   {
+      f->Close();
+      {
+         XrdSysCondVarHelper lock(&m_active_cond);
+         m_active.erase(act_it);
+      }
+
+      if (m_gstream)
+      {
+         const Stats       &st = f->RefStats();
+         const Info::AStat *as = f->GetLastAccessStats();
+
+         char buf[4096];
+         int  len = snprintf(buf, 4096, "{\"event\":\"file_close\","
+                              "\"lfn\":\"%s\",\"size\":%lld,\"blk_size\":%d,\"n_blks\":%d,\"n_blks_done\":%d,"
+                              "\"access_cnt\":%lu,\"attach_t\":%lld,\"detach_t\":%lld,\"remotes\":%s,"
+                              "\"b_hit\":%lld,\"b_miss\":%lld,\"b_bypass\":%lld,"
+                              "\"b_todisk\":%lld,\"b_prefetch\":%lld,\"n_cks_errs\":%d}",
+                              f->GetLocalPath().c_str(), f->GetFileSize(), f->GetBlockSize(),
+                              f->GetNBlocks(), f->GetNDownloadedBlocks(),
+                              (unsigned long) f->GetAccessCnt(), (long long) as->AttachTime, (long long) as->DetachTime,
+                              f->GetRemoteLocations().c_str(),
+                              as->BytesHit, as->BytesMissed, as->BytesBypassed,
+                              st.m_BytesWritten, f->GetPrefetchedBytes(), st.m_NCksumErrors
+         );
+         bool suc = false;
+         if (len < 4096)
+         {
+            suc = m_gstream->Insert(buf, len + 1);
+         }
+         if ( ! suc)
+         {
+            TRACE(Error, "Failed g-stream insertion of file_close record, len=" << len);
+         }
+      }
+
+      delete f;
+   }
 }
 
-bool Cache::IsFileActiveOrPurgeProtected(const std::string& path)
+bool Cache::IsFileActiveOrPurgeProtected(const std::string& path) const
 {
    XrdSysCondVarHelper lock(&m_active_cond);
 
@@ -689,6 +681,11 @@ bool Cache::IsFileActiveOrPurgeProtected(const std::string& path)
           m_purge_delay_set.find(path) != m_purge_delay_set.end();
 }
 
+void Cache::ClearPurgeProtectedSet()
+{
+   XrdSysCondVarHelper lock(&m_active_cond);
+   m_purge_delay_set.clear();
+}
 
 //==============================================================================
 //=== PREFETCH
@@ -1014,7 +1011,13 @@ int Cache::ConsiderCached(const char *curl)
       auto it = m_active.find(f_name);
       if (it != m_active.end()) {
          file = it->second;
-         inc_ref_cnt(file, false, false);
+         // If the file-open is in progress, `file` is a nullptr
+         // so we cannot increase the reference count.  For now,
+         // simply treat it as if the file open doesn't exist instead
+         // of trying to wait and see if it succeeds.
+         if (file) {
+            inc_ref_cnt(file, false, false);
+         }
       }
    }
    if (file) {
@@ -1123,7 +1126,12 @@ int Cache::Stat(const char *curl, struct stat &sbuff)
       auto it = m_active.find(f_name);
       if (it != m_active.end()) {
          file = it->second;
-         inc_ref_cnt(file, false, false);
+         // If `file` is nullptr, the file-open is in progress; instead
+         // of waiting for the file-open to finish, simply treat it as if
+         // the file-open doesn't exist.
+         if (file) {
+            inc_ref_cnt(file, false, false);
+         }
       }
    }
    if (file) {
@@ -1178,8 +1186,10 @@ int Cache::Unlink(const char *curl)
 
 int Cache::UnlinkFile(const std::string& f_name, bool fail_if_open)
 {
+   static const char* trc_pfx = "UnlinkFile ";
    ActiveMap_i  it;
    File        *file = 0;
+   long long    st_blocks_to_purge = 0;
    {
       XrdSysCondVarHelper lock(&m_active_cond);
 
@@ -1189,7 +1199,7 @@ int Cache::UnlinkFile(const std::string& f_name, bool fail_if_open)
       {
          if (fail_if_open)
          {
-            TRACE(Info, "UnlinkCommon " << f_name << ", file currently open and force not requested - denying request");
+            TRACE(Info, trc_pfx << f_name << ", file currently open and force not requested - denying request");
             return -EBUSY;
          }
 
@@ -1197,12 +1207,12 @@ int Cache::UnlinkFile(const std::string& f_name, bool fail_if_open)
          // Attach() with possible File::Open(). Ask for retry.
          if (it->second == 0)
          {
-            TRACE(Info, "UnlinkCommon " << f_name << ", an operation on this file is ongoing - denying request");
+            TRACE(Info, trc_pfx << f_name << ", an operation on this file is ongoing - denying request");
             return -EAGAIN;
          }
 
          file = it->second;
-         file->initiate_emergency_shutdown();
+         st_blocks_to_purge = file->initiate_emergency_shutdown();
          it->second = 0;
       }
       else
@@ -1211,9 +1221,12 @@ int Cache::UnlinkFile(const std::string& f_name, bool fail_if_open)
       }
    }
 
-   if (file)
-   {
+   if (file) {
       RemoveWriteQEntriesFor(file);
+   } else {
+      struct stat f_stat;
+      if (m_oss->Stat(f_name.c_str(), &f_stat) == XrdOssOK)
+         st_blocks_to_purge = f_stat.st_blocks;
    }
 
    std::string i_name = f_name + Info::s_infoExtension;
@@ -1222,7 +1235,10 @@ int Cache::UnlinkFile(const std::string& f_name, bool fail_if_open)
    int f_ret = m_oss->Unlink(f_name.c_str());
    int i_ret = m_oss->Unlink(i_name.c_str());
 
-   TRACE(Debug, "UnlinkCommon " << f_name << ", f_ret=" << f_ret << ", i_ret=" << i_ret);
+   if (st_blocks_to_purge)
+      m_res_mon->register_file_purge(f_name, st_blocks_to_purge);
+
+   TRACE(Debug, trc_pfx << f_name << ", f_ret=" << f_ret << ", i_ret=" << i_ret);
 
    {
       XrdSysCondVarHelper lock(&m_active_cond);
