@@ -18,21 +18,21 @@
 
 
 #include "XrdPfcFile.hh"
+#include "XrdPfc.hh"
+#include "XrdPfcResourceMonitor.hh"
 #include "XrdPfcIO.hh"
 #include "XrdPfcTrace.hh"
-#include <cstdio>
-#include <sstream>
-#include <fcntl.h>
-#include <assert.h>
-#include "XrdCl/XrdClLog.hh"
-#include "XrdCl/XrdClConstants.hh"
-#include "XrdCl/XrdClFile.hh"
-#include "XrdSys/XrdSysPthread.hh"
+
+#include "XProtocol/XProtocol.hh"
 #include "XrdSys/XrdSysTimer.hh"
 #include "XrdOss/XrdOss.hh"
 #include "XrdOuc/XrdOucEnv.hh"
 #include "XrdSfs/XrdSfsInterface.hh"
-#include "XrdPfc.hh"
+
+#include <cstdio>
+#include <sstream>
+#include <fcntl.h>
+#include <cassert>
 
 
 using namespace XrdPfc;
@@ -67,6 +67,7 @@ File::File(const std::string& path, long long iOffset, long long iFileSize) :
    m_state_cond(0),
    m_block_size(0),
    m_num_blocks(0),
+   m_resmon_token(-1),
    m_prefetch_state(kOff),
    m_prefetch_bytes(0),
    m_prefetch_read_cnt(0),
@@ -76,23 +77,60 @@ File::File(const std::string& path, long long iOffset, long long iFileSize) :
 
 File::~File()
 {
+   TRACEF(Debug, "~File() for ");
+}
+
+void File::Close()
+{
+   // Close is called while nullptr is put into Cache::m_active map, see Cache::dec_ref_count(File*).
+   // A stat is called after close to re-check that m_stat_blocks have been reported correctly
+   // to the resource-monitor. Note that the reporting is already clamped down to m_file_size
+   // in report_and_merge_delta_stats() below.
+   //
+   // XFS can pre-allocate significant amount of blocks (1 GB at 1GB mark, 4 GB above 4GB) and those
+   // get reported in as stat.st_blocks.
+   // The reported number is correct in a stat immediately following a close.
+   // If one starts off by writing the last byte of the file, this pre-allocation does not get
+   // triggered up to that point. But comes back with a vengeance right after.
+   //
+   // To be determined if other FSes do something similar (Ceph, ZFS, ...). Ext4 doesn't.
+
    if (m_info_file)
    {
-      TRACEF(Debug, "~File() close info ");
+      TRACEF(Debug, "Close() closing info-file ");
       m_info_file->Close();
       delete m_info_file;
-      m_info_file = NULL;
+      m_info_file = nullptr;
    }
 
    if (m_data_file)
    {
-      TRACEF(Debug, "~File() close output  ");
+      TRACEF(Debug, "Close() closing data-file ");
       m_data_file->Close();
       delete m_data_file;
-      m_data_file = NULL;
+      m_data_file = nullptr;
    }
 
-   TRACEF(Debug, "~File() ended, prefetch score = " <<  m_prefetch_score);
+   if (m_resmon_token >= 0)
+   {
+      // Last update of file stats has been sent from the final Sync unless we are in_shutdown --
+      // but in this case the file will get unlinked by the cache and reported as purge event.
+      // We check if the reported st_blocks so far is correct.
+      if (m_stats.m_BytesWritten > 0 && ! m_in_shutdown) {
+         struct stat s;
+         int sr = Cache::GetInstance().GetOss()->Stat(m_filename.c_str(), &s);
+         if (sr == 0 && s.st_blocks != m_st_blocks) {
+            Stats stats;
+            stats.m_StBlocksAdded = s.st_blocks - m_st_blocks;
+            m_st_blocks = s.st_blocks;
+            Cache::ResMon().register_file_update_stats(m_resmon_token, stats);
+         }
+      }
+
+      Cache::ResMon().register_file_close(m_resmon_token, time(0), m_stats);
+   }
+
+   TRACEF(Debug, "Close() finished, prefetch score = " <<  m_prefetch_score);
 }
 
 //------------------------------------------------------------------------------
@@ -110,7 +148,7 @@ File* File::FileOpen(const std::string &path, long long offset, long long fileSi
 
 //------------------------------------------------------------------------------
 
-void File::initiate_emergency_shutdown()
+long long File::initiate_emergency_shutdown()
 {
    // Called from Cache::Unlink() when the file is currently open.
    // Cache::Unlink is also called on FSync error and when wrong number of bytes
@@ -121,36 +159,48 @@ void File::initiate_emergency_shutdown()
    //
    // File's entry in the Cache's active map is set to nullptr and will be
    // removed from there shortly, in any case, well before this File object
-   // shuts down. So we do not communicate to Cache about our destruction when
-   // it happens.
+   // shuts down. Cache::Unlink() also reports the appropriate purge event.
 
+   XrdSysCondVarHelper _lck(m_state_cond);
+
+   m_in_shutdown = true;
+
+   if (m_prefetch_state != kStopped && m_prefetch_state != kComplete)
    {
-      XrdSysCondVarHelper _lck(m_state_cond);
-
-      m_in_shutdown = true;
-
-      if (m_prefetch_state != kStopped && m_prefetch_state != kComplete)
-      {
-         m_prefetch_state = kStopped;
-         cache()->DeRegisterPrefetchFile(this);
-      }
+      m_prefetch_state = kStopped;
+      cache()->DeRegisterPrefetchFile(this);
    }
 
+   report_and_merge_delta_stats();
+
+   return m_st_blocks;
 }
 
 //------------------------------------------------------------------------------
 
-Stats File::DeltaStatsFromLastCall()
+void File::check_delta_stats()
 {
-   // Not locked, only used from Cache / Purge thread.
+   // Called under m_state_cond lock.
+   // BytesWritten indirectly trigger an unconditional merge through periodic Sync().
+   if (m_delta_stats.BytesReadAndWritten() >= m_resmon_report_threshold && ! m_in_shutdown)
+      report_and_merge_delta_stats();
+}
 
-   Stats delta = m_last_stats;
-
-   m_last_stats = m_stats.Clone();
-
-   delta.DeltaToReference(m_last_stats);
-
-   return delta;
+void File::report_and_merge_delta_stats()
+{
+   // Called under m_state_cond lock.
+   struct stat s;
+   m_data_file->Fstat(&s);
+   // Do not report st_blocks beyond 4kB round-up over m_file_size. Some FSs report
+   // aggressive pre-allocation in this field (XFS, 4GB).
+   long long max_st_blocks_to_report = (m_file_size & 0xfff) ? ((m_file_size >> 12) + 1) << 3
+                                                             :   m_file_size >> 9;
+   long long st_blocks_to_report = std::min((long long) s.st_blocks, max_st_blocks_to_report);
+   m_delta_stats.m_StBlocksAdded = st_blocks_to_report - m_st_blocks;
+   m_st_blocks = st_blocks_to_report;
+   Cache::ResMon().register_file_update_stats(m_resmon_token, m_delta_stats);
+   m_stats.AddUp(m_delta_stats);
+   m_delta_stats.Reset();
 }
 
 //------------------------------------------------------------------------------
@@ -279,8 +329,8 @@ bool File::FinalizeSyncBeforeExit()
    {
      if ( ! m_writes_during_sync.empty() || m_non_flushed_cnt > 0 || ! m_detach_time_logged)
      {
-       Stats loc_stats = m_stats.Clone();
-       m_cfi.WriteIOStatDetach(loc_stats);
+       report_and_merge_delta_stats();
+       m_cfi.WriteIOStatDetach(m_stats);
        m_detach_time_logged = true;
        m_in_sync            = true;
        TRACEF(Debug, "FinalizeSyncBeforeExit requesting sync to write detach stats");
@@ -310,7 +360,7 @@ void File::AddIO(IO *io)
    {
       m_io_set.insert(io);
       io->m_attach_time = now;
-      m_stats.IoAttach();
+      m_delta_stats.IoAttach();
 
       insert_remote_location(loc);
 
@@ -349,7 +399,7 @@ void File::RemoveIO(IO *io)
          ++m_current_io;
       }
 
-      m_stats.IoDetach(now - io->m_attach_time);
+      m_delta_stats.IoDetach(now - io->m_attach_time);
       m_io_set.erase(mi);
       --m_ios_in_detach;
 
@@ -376,7 +426,11 @@ bool File::Open()
 
    static const char *tpfx = "Open() ";
 
-   TRACEF(Dump, tpfx << "open file for disk cache");
+   TRACEF(Dump, tpfx << "entered");
+
+   // Before touching anything, check with ResourceMonitor if a scan is in progress.
+   // This function will wait internally if needed until it is safe to proceed.
+   Cache::ResMon().CrossCheckIfScanIsInProgress(m_filename, m_state_cond);
 
    const Configuration &conf = Cache::GetInstance().RefConfiguration();
 
@@ -413,7 +467,7 @@ bool File::Open()
       return false;
    }
 
-   myEnv.Put("oss.asize", "64k"); // TODO: Calculate? Get it from configuration? Do not know length of access lists ...
+   myEnv.Put("oss.asize", "64k"); // Advisory, block-map and access list lengths vary.
    myEnv.Put("oss.cgroup", conf.m_meta_space.c_str());
    if ((res = myOss.Create(myUser, ifn.c_str(), 0600, myEnv, XRDOSS_mkpath)) != XrdOssOK)
    {
@@ -449,6 +503,7 @@ bool File::Open()
          TRACEF(Warning, tpfx << "Basic sanity checks on data file failed, resetting info file, truncating data file.");
          m_cfi.ResetAllAccessStats();
          m_data_file->Ftruncate(0);
+         Cache::ResMon().register_file_purge(m_filename, data_stat.st_blocks);
       }
    }
 
@@ -461,6 +516,7 @@ bool File::Open()
          initialize_info_file = true;
          m_cfi.ResetAllAccessStats();
          m_data_file->Ftruncate(0);
+         Cache::ResMon().register_file_purge(m_filename, data_stat.st_blocks);
       } else {
          // TODO: If the file is complete, we don't need to reset net cksums.
          m_cfi.DowngradeCkSumState(conf.get_cs_Chk());
@@ -477,12 +533,28 @@ bool File::Open()
       cache()->WriteFileSizeXAttr(m_info_file->getFD(), m_file_size);
       TRACEF(Debug, tpfx << "Creating new file info, data size = " <<  m_file_size << " num blocks = "  << m_cfi.GetNBlocks());
    }
+   else
+   {
+      if (futimens(m_info_file->getFD(), NULL)) {
+         TRACEF(Error, tpfx << "failed setting modification time " << ERRNO_AND_ERRSTR(errno));
+      }
+   }
 
    m_cfi.WriteIOStatAttach();
    m_state_cond.Lock();
    m_block_size = m_cfi.GetBufferSize();
    m_num_blocks = m_cfi.GetNBlocks();
    m_prefetch_state = (m_cfi.IsComplete()) ? kComplete : kStopped; // Will engage in AddIO().
+
+   m_data_file->Fstat(&data_stat);
+   m_st_blocks = data_stat.st_blocks;
+
+   m_resmon_token = Cache::ResMon().register_file_open(m_filename, time(0), data_existed);
+   constexpr long long MB = 1024 * 1024;
+   m_resmon_report_threshold = std::min(std::max(10 * MB, m_file_size / 20), 500 * MB);
+   // m_resmon_report_threshold_scaler; // something like 10% of original threshold, to adjust
+   // actual threshold based on return values from register_file_update_stats().
+
    m_state_cond.UnLock();
 
    return true;
@@ -695,7 +767,11 @@ int File::Read(IO *io, char* iUserBuff, long long iUserOff, int iUserSize, ReadR
    {
       m_state_cond.UnLock();
       int ret = m_data_file->Read(iUserBuff, iUserOff, iUserSize);
-      if (ret > 0) m_stats.AddBytesHit(ret);
+      if (ret > 0) {
+         XrdSysCondVarHelper _lck(m_state_cond);
+         m_delta_stats.AddBytesHit(ret);
+         check_delta_stats();
+      }
       return ret;
    }
 
@@ -724,7 +800,11 @@ int File::ReadV(IO *io, const XrdOucIOVec *readV, int readVnum, ReadReqRH *rh)
    {
       m_state_cond.UnLock();
       int ret = m_data_file->ReadV(const_cast<XrdOucIOVec*>(readV), readVnum);
-      if (ret > 0) m_stats.AddBytesHit(ret);
+      if (ret > 0) {
+         XrdSysCondVarHelper _lck(m_state_cond);
+         m_delta_stats.AddBytesHit(ret);
+         check_delta_stats();
+      }
       return ret;
    }
 
@@ -954,10 +1034,10 @@ int File::ReadOpusCoalescere(IO *io, const XrdOucIOVec *readV, int readVnum,
       if (read_req->is_complete())
       {
          // Almost like FinalizeReadRequest(read_req) -- but no callout!
+         m_delta_stats.AddReadStats(read_req->m_stats);
+         check_delta_stats();
          m_state_cond.UnLock();
 
-         m_stats.AddReadStats(read_req->m_stats);
-
          int ret = read_req->return_value();
          delete read_req;
          return ret;
@@ -970,7 +1050,8 @@ int File::ReadOpusCoalescere(IO *io, const XrdOucIOVec *readV, int readVnum,
    }
    else
    {
-      m_stats.m_BytesHit += bytes_read;
+      m_delta_stats.m_BytesHit += bytes_read;
+      check_delta_stats();
       m_state_cond.UnLock();
 
       // !!! No callout.
@@ -1001,12 +1082,9 @@ void File::WriteBlockToDisk(Block* b)
 
    if (retval < size)
    {
-      if (retval < 0)
-      {
-         GetLog()->Emsg("WriteToDisk()", -retval, "write block to disk", GetLocalPath().c_str());
-      }
-      else
-      {
+      if (retval < 0) {
+         TRACEF(Error, "WriteToDisk() write error " << retval);
+      } else {
          TRACEF(Error, "WriteToDisk() incomplete block write ret=" << retval << " (should be " << size << ")");
       }
 
@@ -1075,7 +1153,12 @@ void File::Sync()
    bool errorp = false;
    if (ret == XrdOssOK)
    {
-      Stats loc_stats = m_stats.Clone();
+      Stats loc_stats;
+      {
+         XrdSysCondVarHelper _lck(&m_state_cond);
+         report_and_merge_delta_stats();
+         loc_stats = m_stats;
+      }
       m_cfi.WriteIOStat(loc_stats);
       m_cfi.Write(m_info_file, m_filename.c_str());
       int cret = m_info_file->Fsync();
@@ -1289,8 +1372,11 @@ void File::FinalizeReadRequest(ReadRequest *rreq)
 {
    // called from ProcessBlockResponse()
    // NOT under lock -- does callout
-
-   m_stats.AddReadStats(rreq->m_stats);
+   {
+      XrdSysCondVarHelper _lck(m_state_cond);
+      m_delta_stats.AddReadStats(rreq->m_stats);
+      check_delta_stats();
+   }
 
    rreq->m_rh->Done(rreq->return_value());
    delete rreq;
@@ -1360,7 +1446,8 @@ void File::ProcessBlockResponse(Block *b, int res)
       {
          // Increase ref-count for the writer.
          inc_ref_count(b);
-         m_stats.AddWriteStats(b->get_size(), b->get_n_cksum_errors());
+         m_delta_stats.AddWriteStats(b->get_size(), b->get_n_cksum_errors());
+         // No check for writes, report-and-merge forced during Sync().
          cache()->AddWriteTask(b, true);
       }
 
