@@ -108,7 +108,7 @@ void Cleanup(const std::set<std::string> &Contacts, const XrdSecEntity &Entity)
 
    for (it = Contacts.begin(); it != Contacts.end(); it++)
        {if (Blab) DMSG("Cleanup", "Disconnecting " <<(*it).c_str());
-        PostMaster->ForceDisconnect(XrdCl::URL(*it));}
+        PostMaster->ForceDisconnect(XrdCl::URL(*it), true);}
 }
 
       ConCleanup(XrdCl::PostMaster *pm, bool dbg) : PostMaster(pm), Blab(dbg) {}
@@ -563,7 +563,7 @@ int XrdPosixConfig::Stats(const char *theID, char *buff, int blen)
    static const char stats2[] = "<stats id=\"cache\" type=\"%s\">"
           "<prerd><in>%lld</in><hits>%lld</hits><miss>%lld</miss></prerd>"
           "<rd><in>%lld</in><out>%lld</out>"
-              "<hits>%lld></hits><miss>%lld</miss>"
+              "<hits>%lld</hits><miss>%lld</miss>"
           "</rd>"
           "<pass>%lld<cnt>%lld</cnt></pass>"
           "<wr><out>%lld</out><updt>%lld</updt></wr>"
