@@ -2,8 +2,6 @@
  * Implementation of multi-stream HTTP transfers for the TPCHandler
  */
 
-#ifdef XRD_CHUNK_RESP
-
 #include "XrdTpcTPC.hh"
 #include "XrdTpcState.hh"
 #include "XrdTpcCurlMulti.hh"
@@ -260,17 +258,11 @@ int TPCHandler::RunCurlWithStreamsImpl(XrdHttpExtReq &req, State &state,
     size_t streams, std::vector<State*> &handles,
     std::vector<ManagedCurlHandle> &curl_handles, TPCLogRecord &rec)
 {
-    int result;
     bool success;
-    CURL *curl = state.GetHandle();
-    if ((result = DetermineXferSize(curl, req, state, success, rec)) || !success) {
-        return result;
-    }
+    // The content-length was set thanks to the call to GetContentLengthTPCPull() before calling this function
     off_t content_size = state.GetContentLength();
     off_t current_offset = 0;
 
-    state.ResetAfterRequest();    
-
     size_t concurrency = streams * m_pipelining_multiplier;
 
     handles.reserve(concurrency);
@@ -553,6 +545,4 @@ int TPCHandler::RunCurlWithStreams(XrdHttpExtReq &req, State &state,
         }
         return req.ChunkResp(NULL, 0);
     }
-}
-
-#endif // XRD_CHUNK_RESP
+}
\ No newline at end of file
