@@ -468,7 +468,7 @@ int TPCHandler::GetContentLengthTPCPull(CURL *curl, XrdHttpExtReq &req, uint64_t
     State state(curl,req.tpcForwardCreds);
     //Don't forget to copy the headers of the client's request before doing the HEAD call. Otherwise, if there is a need for authentication,
     //it will fail
-    state.CopyHeaders(req);
+    state.SetupHeaders(req);
     int result;
     //In case we cannot get the content length, we return the error to the client
     if ((result = DetermineXferSize(curl, req, state, success, rec)) || !success) {
@@ -857,7 +857,7 @@ int TPCHandler::ProcessPushReq(const std::string & resource, XrdHttpExtReq &req)
 
     Stream stream(std::move(fh), 0, 0, m_log);
     State state(0, stream, curl, true, req.tpcForwardCreds);
-    state.CopyHeaders(req);
+    state.SetupHeaders(req);
 
     return RunCurlWithUpdates(curl, req, state, rec);
 }
@@ -1009,7 +1009,7 @@ int TPCHandler::ProcessPullReq(const std::string &resource, XrdHttpExtReq &req)
     }
     Stream stream(std::move(fh), streams * m_pipelining_multiplier, streams > 1 ? m_block_size : m_small_block_size, m_log);
     State state(0, stream, curl, false, req.tpcForwardCreds);
-    state.CopyHeaders(req);
+    state.SetupHeaders(req);
     state.SetContentLength(sourceFileContentLength);
 
     if (streams > 1) {
